.. _translating:

Translating Isomer
==================

Since 2018, we have all parts (Backend, Frontend, Modules) prepared for translations.

To translate Isomer, you can use `Transifex <https://www.transifex.com/isomeric-community/isomer/>`__
or any PO editor of your choice.